# trn-sim
Simulation on financial market transaction (eg. Stock buy&sell). 
Imagining you have a trading account, you can do buy & sell actions. You can build the trn history once you take the action and provide functions for calculation of FF(Fund Flow) and GL(Gain & Loss). 

# Version 1.0
A very simple and conding version. You have to write your own python logic to decide when you buy or sell. But it will help you recording and computing your result.


